irl\_benchmark.irl.feature package
==================================

Submodules
----------

irl\_benchmark.irl.feature.feature\_wrapper module
--------------------------------------------------

.. automodule:: irl_benchmark.irl.feature.feature_wrapper
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: irl_benchmark.irl.feature
    :members:
    :undoc-members:
    :show-inheritance:
